@@ -55,7 +55,7 @@ use warnings;
 use FBP           0.31 ();
 use Data::Dumper 2.122 ();
 
-our $VERSION = '0.45';
+our $VERSION = '0.46';
 
 # Event Binding Table
 my %EVENT = (
@@ -170,6 +170,11 @@ my %EVENT = (
 	OnSplitterSashPosChanged  => [ 'EVT_SPLITTER_SASH_POS_CHANGED'  ],
 	OnSplitterUnsplit         => [ 'EVT_SPLITTER_UNSPLIT'           ],
 	OnSplitterDClick          => [ 'EVT_SPLITTER_DCLICK'            ],
+
+	# Toolbar events
+	OnToolClicked             => [ '' ],
+	OnToolRClicked            => [ '' ],
+	OnToolEnter               => [ '' ],
 );
 
 
@@ -722,6 +727,8 @@ sub window_create {
 		$lines = $self->statusbar_create($window, $parent);
 	} elsif ( $window->isa('FBP::TextCtrl') ) {
 		$lines = $self->textctrl_create($window, $parent);
+	} elsif ( $window->isa('FBP::ToolBar') ) {
+		$lines = $self->toolbar_create($window, $parent);
 	} else {
 		die 'Cannot create constructor code for ' . ref($window);
 	}
@@ -1444,6 +1451,50 @@ sub textctrl_create {
 	return $lines;
 }
 
+sub tool_create {
+	my $self    = shift;
+	my $tool    = shift;
+	my $parent  = $self->object_parent(@_);
+	my $id      = $self->wx( $tool->id );
+	my $label   = $self->object_label($tool);
+	my $bitmap  = $self->bitmap( $tool->bitmap );
+	my $tooltip = $self->text( $tool->tooltip );
+	my $kind    = $self->wx( $tool->kind );
+
+	return $self->nested(
+		"$parent->AddTool(",
+		"$id,",
+		"$label,",
+		"$bitmap,",
+		"$tooltip,",
+		"$kind,",
+		");",
+	);
+}
+
+sub toolbar_create {
+	my $self     = shift;
+	my $window   = shift;
+	my $parent   = $self->object_parent(@_);
+	my $scope    = $self->object_scope($window);
+	my $variable = $self->object_variable($window);
+	my $style    = $self->wx($window->styles || 0);
+	my $id       = $self->wx( $window->id );
+
+	# Generate child constructor code
+	my @children = map {
+		$_->isa('FBP::Tool')
+		? $self->tool_create($_, $window)
+		: "$variable->AddSeparator;"
+	} @{$window->children};
+
+	return [
+		"$scope$variable = $parent->CreateToolBar( $style, $id );",
+		( map { ref $_ ? @$_ : $_ } @children ),
+		"$variable->Realize;",
+	];
+}
+
 sub treebook_create {
 	my $self     = shift;
 	my $control  = shift;
@@ -2299,6 +2350,17 @@ sub points {
 	$self->wx('wxNORMAL_FONT') . '->GetPointSize';
 }
 
+sub bitmap {
+	my $self   = shift;
+	my $bitmap = shift;
+	unless ( defined $bitmap ) {
+		return $self->wx('wxNullBitmap');
+	}
+
+	### To be completed
+	return $self->wx('wxNullBitmap');
+}
+
 sub indent {
 	map { /\S/ ? "\t$_" : $_ } @{$_[1]};
 }
